import { forwardRef, useState, useRef, useCallback, useEffect, Children, cloneElement } from 'react';
import { css, jsx } from '@emotion/core';
import debounce from 'lodash.debounce';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var checkBottomPosition = function checkBottomPosition(el, elMenu) {
  var DropdownBoundingClientRect = el.getBoundingClientRect();
  var offsetTop = DropdownBoundingClientRect.top + window.scrollY + elMenu.offsetHeight;
  var outerHeight = el.offsetHeight;
  var windowInnerHeight = window.innerHeight;
  var windowScrollTop = window.pageYOffset;
  return offsetTop + outerHeight > windowInnerHeight + windowScrollTop;
};
var checkRightPosition = function checkRightPosition(el) {
  var DropdownBoundingClientRect = el.getBoundingClientRect();
  var offsetLeft = DropdownBoundingClientRect.right + window.scrollX;
  var outerHeight = el.offsetWidth;
  var windowInnerWidth = window.innerWidth;
  var windowScrollLeft = window.pageXOffset;
  return offsetLeft + outerHeight > windowInnerWidth + windowScrollLeft;
};

var _templateObject;

var DropdownItem = function DropdownItem(props) {
  var className = props.className,
      otherProps = _objectWithoutPropertiesLoose(props, ["className"]);

  var DropdownItemStyle = css(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["\n    padding: 10px 12px 10px 12px;\n    font-size: 14px;\n    line-height: 1.3;\n    cursor: pointer;\n    white-space: nowrap;\n    overflow: hidden;\n    text-overflow: ellipsis;\n    text-align: left;\n\n    &:hover {\n      background-color: rgba(243, 244, 246, 1);\n      color: inherit;\n    }\n\n    &:active {\n      background-color: #eeeeee;\n    }\n\n    &.selected {\n      background-color: rgba(243, 244, 246, 1);\n    }\n  "])));
  return jsx("div", Object.assign({
    css: DropdownItemStyle,
    className: className
  }, otherProps), props.children);
};

DropdownItem.displayName = 'DropdownItem';

var _templateObject$1;

var Svg = function Svg(p) {
  return jsx("svg", Object.assign({
    width: "24",
    height: "24",
    viewBox: "0 0 24 24",
    focusable: "false",
    role: "presentation"
  }, p));
};

var ChevronDown = function ChevronDown(props) {
  return jsx(Svg, Object.assign({
    style: {
      marginRight: -6,
      marinLeft: 6
    }
  }, props), jsx("path", {
    d: "M8.292 10.293a1.009 1.009 0 0 0 0 1.419l2.939 2.965c.218.215.5.322.779.322s.556-.107.769-.322l2.93-2.955a1.01 1.01 0 0 0 0-1.419.987.987 0 0 0-1.406 0l-2.298 2.317-2.307-2.327a.99.99 0 0 0-1.406 0z",
    fill: "currentColor",
    fillRule: "evenodd"
  }));
};

var DropdownToggle = function DropdownToggle(props) {
  var disabled = props.disabled,
      _onClick = props.onClick,
      label = props.label,
      icon = props.icon,
      otherProps = _objectWithoutPropertiesLoose(props, ["disabled", "onClick", "label", "icon"]);

  var DropdownToggleStyle = css(_templateObject$1 || (_templateObject$1 = _taggedTemplateLiteralLoose(["\n    display: inline-flex;\n    justify-content: space-between;\n    align-items: center;\n    padding: 0.5rem 1rem;\n    cursor: pointer;\n    border-radius: 0.375rem;\n    background-color: #ffffff;\n    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.5);\n    font-weight: 500;\n  "])));
  return jsx("div", Object.assign({
    css: DropdownToggleStyle,
    onClick: function onClick(e) {
      return !disabled ? _onClick(e) : undefined;
    }
  }, otherProps), label, !icon ? jsx(ChevronDown, null) : icon);
};

DropdownToggle.defaultProps = {
  disabled: false,
  label: 'Dropdown'
};
DropdownToggle.displayName = 'DropdownToggle';

var _templateObject$2;
var DropdownMenu = /*#__PURE__*/forwardRef(function (props, ref) {
  var isBottom = props.isBottom,
      isRight = props.isRight,
      otherProps = _objectWithoutPropertiesLoose(props, ["isBottom", "isRight"]);

  var DropdownMenuStyle = css(_templateObject$2 || (_templateObject$2 = _taggedTemplateLiteralLoose(["\n      background-color: #ffffff;\n      border-radius: 0.375rem;\n      box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1),\n        0 1px 2px 0 rgba(0, 0, 0, 0.06);\n      margin-top: ", ";\n      margin-bottom: ", ";\n      position: absolute;\n      z-index: 10;\n      min-width: 200px;\n      max-height: 300px;\n      overflow: auto;\n      padding-top: 0.25rem;\n      padding-bottom: 0.25rem;\n      opacity: 1;\n      top: ", ";\n      bottom: ", ";\n      right: ", ";\n    "])), !isBottom ? '0.5rem' : '0px', isBottom ? '0.5rem' : '0px', isBottom ? 'auto' : 'initial', isBottom ? '100%' : 'initial', isRight ? '0px' : 'initial');
  return jsx("div", Object.assign({
    ref: ref,
    css: DropdownMenuStyle
  }, otherProps), props.children);
});
DropdownMenu.defaultProps = {
  isBottom: true
};
DropdownMenu.displayName = 'DropdownMenu';

var _templateObject$3;

var Dropdown = function Dropdown(props) {
  var show = props.show,
      label = props.label,
      disabled = props.disabled,
      onClose = props.onClose,
      className = props.className,
      uncontrolled = props.uncontrolled,
      icon = props.icon,
      otherProps = _objectWithoutPropertiesLoose(props, ["show", "label", "disabled", "onClose", "className", "uncontrolled", "icon"]);

  var _React$useState = useState(show || false),
      isOpen = _React$useState[0],
      setOpen = _React$useState[1];

  var _React$useState2 = useState(false),
      isBottomPosition = _React$useState2[0],
      setBottomPosition = _React$useState2[1];

  var _React$useState3 = useState(false),
      isRightPosition = _React$useState3[0],
      setRightPosition = _React$useState3[1];

  var refDropdown = useRef(null);
  var refMenu = useRef(null);
  var handleClickOutside = useCallback(function (event) {
    var _refDropdown$current;

    if (!(refDropdown != null && (_refDropdown$current = refDropdown.current) != null && _refDropdown$current.contains(event.target))) {
      setOpen(false);
      !!onClose && onClose();
    }
  }, [onClose]);
  var handleClick = useCallback(function () {
    setOpen(!isOpen);

    if (isOpen) {
      !!onClose && onClose();
    }
  }, [isOpen, onClose]);
  var handleScroll = useCallback(debounce(function () {
    if (refDropdown.current && refMenu.current) {
      var isBottom = checkBottomPosition(refDropdown.current, refMenu.current);
      setBottomPosition(isBottom);
      var isRight = checkRightPosition(refDropdown.current);
      setRightPosition(isRight);
    }
  }, 50), [checkBottomPosition]);
  useEffect(function () {
    setOpen(show || false);
  }, [show]);
  useEffect(function () {
    handleScroll();
    document.addEventListener('mousedown', handleClickOutside);
    document.addEventListener('scroll', handleScroll);
    return function () {
      document.removeEventListener('mousedown', handleClickOutside);
      document.removeEventListener('scroll', handleScroll);
    };
  }, [handleClickOutside, handleScroll]);
  var DropdownStyle = css(_templateObject$3 || (_templateObject$3 = _taggedTemplateLiteralLoose(["\n    position: relative;\n    font-size: 14px;\n    line-height: 20px;\n  "])));
  var isShowMenu = (uncontrolled && isOpen || !uncontrolled && show) && !disabled;
  return jsx("div", Object.assign({
    css: DropdownStyle,
    className: className,
    ref: refDropdown
  }, otherProps), jsx(DropdownToggle, {
    icon: icon,
    disabled: disabled,
    onClick: handleClick,
    label: label
  }), isShowMenu ? jsx(DropdownMenu, {
    ref: refMenu,
    isBottom: isBottomPosition,
    isRight: isRightPosition
  }, Children.map(props.children, function (childNode) {
    return !!childNode ? cloneElement(childNode, {
      onClose: handleClick
    }) : null;
  })) : null);
};

Dropdown.defaultProps = {
  show: false,
  onClose: function onClose() {},
  disabled: false,
  uncontrolled: true
};
var index = /*#__PURE__*/Object.assign(Dropdown, {
  Item: DropdownItem
});

export default index;
//# sourceMappingURL=react-tiny-dropdown.esm.js.map
